package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.IFilterUaService;
import com.mdd.admin.validate.FilterUaCreateValidate;
import com.mdd.admin.validate.FilterUaSearchValidate;
import com.mdd.admin.validate.FilterUaUpdateValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.FilterUaDetailVo;
import com.mdd.admin.vo.FilterUaListedVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.FilterUa;
import com.mdd.common.mapper.FilterUaMapper;
import com.mdd.common.util.DateUtils;
import com.mdd.common.util.TimeUtils;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class FilterUaServiceImpl implements IFilterUaService {
   @Resource
   FilterUaMapper filterUaMapper;

   public PageResult<FilterUaListedVo> list(PageValidate pageValidate, FilterUaSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      QueryWrapper<FilterUa> queryWrapper = new QueryWrapper();
      queryWrapper.orderByDesc("ua_id");
      this.filterUaMapper.setSearch(queryWrapper, searchValidate, new String[]{"like:content:str"});
      IPage<FilterUa> iPage = this.filterUaMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<FilterUaListedVo> list = new LinkedList();
      Iterator var8 = iPage.getRecords().iterator();

      while(var8.hasNext()) {
         FilterUa item = (FilterUa)var8.next();
         FilterUaListedVo vo = new FilterUaListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public FilterUaDetailVo detail(Integer id) {
      FilterUa model = (FilterUa)this.filterUaMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("ua_id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在");
      FilterUaDetailVo vo = new FilterUaDetailVo();
      BeanUtils.copyProperties(model, vo);
      return vo;
   }

   public void add(FilterUaCreateValidate createValidate) {
      FilterUa model = new FilterUa();
      model.setContent(createValidate.getContent());
      model.setCreateTime(DateUtils.getNowDate());
      this.filterUaMapper.insert(model);
   }

   public void edit(FilterUaUpdateValidate updateValidate) {
      FilterUa model = (FilterUa)this.filterUaMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("ua_id", updateValidate.getUaId())).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      model.setContent(updateValidate.getContent());
      this.filterUaMapper.updateById(model);
   }

   public void del(Integer id) {
      FilterUa model = (FilterUa)this.filterUaMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("ua_id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      this.filterUaMapper.delete((Wrapper)(new QueryWrapper()).eq("ua_id", id));
   }
}
